@@ -403,7 +403,6 @@ FI_ENUM(FREE_IMAGE_FORMAT) {
 	FIF_PPMRAW	= 15,
 	FIF_RAS		= 16,
 	FIF_TARGA	= 17,
-	FIF_TIFF	= 18,
 	FIF_WBMP	= 19,
 	FIF_PSD		= 20,
 	FIF_CUT		= 21,
@@ -413,7 +412,6 @@ FI_ENUM(FREE_IMAGE_FORMAT) {
 	FIF_GIF     = 25,
 	FIF_HDR		= 26,
 	FIF_SGI		= 28,
-	FIF_EXR		= 29,
 	FIF_J2K		= 30,
 	FIF_JP2		= 31,
 	FIF_PFM		= 32,
@@ -675,14 +673,6 @@ typedef void (DLL_CALLCONV *FI_InitProc)(Plugin *plugin, int format_id);
 #define BMP_SAVE_RLE        1
 #define CUT_DEFAULT         0
 #define DDS_DEFAULT			0
-#define EXR_DEFAULT			0		//! save data as half with piz-based wavelet compression
-#define EXR_FLOAT			0x0001	//! save data as float instead of as half (not recommended)
-#define EXR_NONE			0x0002	//! save with no compression
-#define EXR_ZIP				0x0004	//! save with zlib compression, in blocks of 16 scan lines
-#define EXR_PIZ				0x0008	//! save with piz-based wavelet compression
-#define EXR_PXR24			0x0010	//! save with lossy 24-bit float compression
-#define EXR_B44				0x0020	//! save with lossy 44% float compression - goes to 22% when combined with EXR_LC
-#define EXR_LC				0x0040	//! save images with one luminance and two chroma channels, rather than as RGB (lossy compression)
 #define GIF_DEFAULT			0
 #define GIF_LOAD256			1		//! load the image as a 256 color image with ununsed palette entries, if it's 16 or 2 color
 #define GIF_PLAYBACK		2		//! 'Play' the GIF to generate each frame (as 32bpp) instead of returning raw frame data when loading
@@ -746,17 +736,6 @@ typedef void (DLL_CALLCONV *FI_InitProc)(Plugin *plugin, int format_id);
 #define TARGA_DEFAULT       0
 #define TARGA_LOAD_RGB888   1       //! if set the loader converts RGB555 and ARGB8888 -> RGB888.
 #define TARGA_SAVE_RLE		2		//! if set, the writer saves with RLE compression
-#define TIFF_DEFAULT        0
-#define TIFF_CMYK			0x0001	//! reads/stores tags for separated CMYK (use | to combine with compression flags)
-#define TIFF_PACKBITS       0x0100  //! save using PACKBITS compression
-#define TIFF_DEFLATE        0x0200  //! save using DEFLATE compression (a.k.a. ZLIB compression)
-#define TIFF_ADOBE_DEFLATE  0x0400  //! save using ADOBE DEFLATE compression
-#define TIFF_NONE           0x0800  //! save without any compression
-#define TIFF_CCITTFAX3		0x1000  //! save using CCITT Group 3 fax encoding
-#define TIFF_CCITTFAX4		0x2000  //! save using CCITT Group 4 fax encoding
-#define TIFF_LZW			0x4000	//! save using LZW compression
-#define TIFF_JPEG			0x8000	//! save using JPEG compression
-#define TIFF_LOGLUV			0x10000	//! save using LogLuv compression
 #define WBMP_DEFAULT        0
 #define XBM_DEFAULT			0
 #define XPM_DEFAULT			0
